=====================
WaterAnalityca Module
=====================

Helper Functions used in the WaterML module to analyze data
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pywaterml.analyzeData
   :members:
   :private-members:
